@@ -1,5 +1,5 @@
 from .morphological_analyzer import analyze_text
 from .fused_stressor import fused_stress_text, fused_stress_replacements, rebuild_text
-from .soap_stressor import stress_text
+from .soap_stressor import stress_text, stress_word
 
-__version__ = '0.0.23'
+__version__ = '0.0.24'
